==> bcusdk_0.0.0.orig.tar.gz: bcusdk-0.0.0/bcu/lib/eewrite.c <==
/*
    BCU SDK bcu development enviroment
    Copyright (C) 2005 Martin Kgler <mkoegler@auto.tuwien.ac.at>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    In addition to the permissions in the GNU General Public License, 
    you may link the compiled version of this file into combinations
    with other programs, and distribute those combinations without any 
    restriction coming from the use of this file. (The General Public 
    License restrictions do apply in other respects; for example, they 
    cover modification of the file, and distribution when not linked into 
    a combine executable.)

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include "bcu_0012.h"

#define NAME(M) eestore_##M
#define HEAD(M) NAME(M)(void* ptr ,unsigned int v __attribute__ ((mode(M))))
HEAD (MODE)
{
  uchar i;
  uchar a = ((short) ptr) & 0xff;
  uchar *v1 = (uchar *) & v;
  for (i = 0; i < sizeof (v); i++, v1++)
    _EEwrite (a + i, *v1);
}

==> bcusdk_0.0.5.tar.gz: bcusdk-0.0.5/bcu/lib/eewrite.c <==
/*
    BCU SDK bcu development enviroment
    Copyright (C) 2005-2011 Martin Koegler <mkoegler@auto.tuwien.ac.at>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    In addition to the permissions in the GNU General Public License, 
    you may link the compiled version of this file into combinations
    with other programs, and distribute those combinations without any 
    restriction coming from the use of this file. (The General Public 
    License restrictions do apply in other respects; for example, they 
    cover modification of the file, and distribution when not linked into 
    a combine executable.)

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/
#include "bcu_0012.h"

#define NAME(M) eestore_##M
#define HEAD(M) NAME(M)(void* ptr ,unsigned int v __attribute__ ((mode(M))))
HEAD (MODE)
{
  uchar i;
  uchar a = ((short) ptr) & 0xff;
  uchar *v1 = (uchar *) & v;
  for (i = 0; i < sizeof (v); i++, v1++)
    _EEwrite (a + i, *v1);
}
